# Generated by Django 4.1.7 on 2023-03-24 16:28

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Estate",
            fields=[
                (
                    "id",
                    models.CharField(max_length=200, primary_key=True, serialize=False),
                ),
                ("created_at", models.DateTimeField(verbose_name="Created date")),
                ("price", models.FloatField(verbose_name="Price")),
            ],
        ),
    ]
